@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Module::CoreList;
 
-our $VERSION = '5.20211120';
+our $VERSION = '5.20211220';
 our %utilities;
 
 sub utilities {
@@ -1755,6 +1755,13 @@ my %delta = (
         removed => {
         }
     },
+    5.035007 => {
+        delta_from => 5.035006,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 %utilities = Module::CoreList::_undelta(\%delta);
